selectiontools.SimultaneousSelection
====================================

.. abjad-lineage:: abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection

.. autoclass:: abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.get_duration
      ~abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.get_spanners
      ~abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.get_vertical_moment_at
      ~abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__add__
      ~abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__contains__
      ~abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__eq__
      ~abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__format__
      ~abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__getitem__
      ~abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__len__
      ~abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__ne__
      ~abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__radd__
      ~abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__repr__

Bases
-----

- :py:class:`selectiontools.Selection <abjad.tools.selectiontools.Selection.Selection>`

- :py:class:`__builtin__.object <object>`

Methods
-------

.. automethod:: abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.get_duration
   :noindex:

.. automethod:: abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.get_spanners
   :noindex:

.. automethod:: abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.get_vertical_moment_at
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__add__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__contains__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__eq__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__format__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__getitem__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__len__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__ne__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__radd__
   :noindex:

.. automethod:: abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection.__repr__
   :noindex:
